UserProvider class abstract interface

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
idKey String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Map<String, dynamic> data) Future<Map<String, dynamic>>
findByEmail(String email) Future<Map<String, dynamic>?>
findById(dynamic id) Future<Map<String, dynamic>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validatePassword(Map<String, dynamic> user, String plainPassword) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited